/**
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package net.amoabeng.util.build;

import net.amoabeng.util.ant.slf4j.Slf4jAntLogger;
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import java.io.File;
import java.io.IOException;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Map;

import static java.lang.String.valueOf;
import static net.amoabeng.util.CompareUtils.nvl;

/**
 * @author Manuel Amoabeng
 */
public class ResourceManagerTask extends Task {


    private String producerType;

    private File projectBaseDir;

    private File projectBuildDir;

    private boolean watch;

    @Override
    public void execute() throws BuildException {

        Slf4jAntLogger.setProject(getProject());

        try {

            Path baseDir = getBaseDir();
            Path buildRoot = getBuildRoot(baseDir);

            @SuppressWarnings({"unchecked"}) Map<String, String> settings = getProject().getProperties();
            settings.put(ResourceManagerProducer.BASE_DIR, baseDir.toString());
            settings.put(ResourceManagerProducer.BUILD_ROOT, buildRoot.toString());
            settings.put(ResourceManagerProducer.PRODUCER_TYPE, getProducerType());
            settings.put(ResourceManagerProducer.BUILD_ON_CHANGE, valueOf(watch));

            BuildUtils.newResourceManager(settings).build();

        } catch (IOException e) {
            throw new BuildException("Error executing ResourceManagerTask: " + e.getMessage(), e);
        }
    }

    private String getProducerType() {
        return nvl(producerType, DefaultResourceManagerProducer.class.getName());
    }

    private Path getBuildRoot(Path baseDir) {
        if (projectBuildDir == null) {
            projectBuildDir = Paths.get("target", getProject().getName()).toFile();
        }
        return baseDir.relativize(projectBuildDir.toPath().normalize().toAbsolutePath());
    }

    private Path getBaseDir() {
        if (projectBaseDir == null) {
            projectBaseDir = getProject().getBaseDir();
        }
        return projectBaseDir.toPath().normalize().toAbsolutePath();
    }

    public void setProducerType(String producerType) {
        this.producerType = producerType;
    }

    public void setProjectBaseDir(File projectBaseDir) {
        this.projectBaseDir = projectBaseDir;
    }

    public void setProjectBuildDir(File projectBuildDir) {
        this.projectBuildDir = projectBuildDir;
    }

    public void setWatch(boolean watch) {
        this.watch = watch;
    }
}
