/**
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package net.amoabeng.util.build;




import java.io.*;
import java.util.Map;
import java.util.logging.LogManager;

import static java.util.Objects.requireNonNull;
import static net.amoabeng.util.CompareUtils.nvl;
import static net.amoabeng.util.ReflectUtils.newInstance;

/**
 * @author Manuel Amoabeng
 */
public class BuildUtils {

    static { // TODO required ?
        try (InputStream in = BuildUtils.class.getResourceAsStream("/logging.properties")) {
            LogManager.getLogManager().readConfiguration(in);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    /**
     * Creates a {@link ResourceManager} with the given settings.
     *
     * {@link DefaultResourceManagerProducer} will be used if there is no class name of another
     * {@link ResourceManagerProducer} stored in settings with key <b>producerType</b>.
     *
     * See {@link ResourceManagerProducer} for further information on its configuration options
     * 
     * @param settings the settings to create a ResourceManager with
     * @return The ResourceManager
     * @throws java.io.IOException if an I/O error occurs
     */
    public static ResourceManager newResourceManager(Map<String, String> settings) throws IOException {
        requireNonNull(settings, "settings is null");
        
        String producerType = nvl(
                settings.get(ResourceManagerProducer.PRODUCER_TYPE),
                DefaultResourceManagerProducer.class.getName());
        
        ResourceManagerProducer resourceManagerProducer = (ResourceManagerProducer) newInstance(producerType);
        return resourceManagerProducer.newResourceManager(settings);
    }


//    public static void invokeResourceManager(
//            Map<String, String> settings,
//            boolean buildOnChange) throws IOException {
//
//        newResourceManager(settings).build(buildOnChange);
//        // TODO
////        if (buildOnChange) {
////            Console console = System.console();
////            boolean exit;
////            do {
////                Thread.sleep(250);
////                exit = console != null && "X".equalsIgnoreCase(console.readLine());
////            }
////            while (!exit);
////        }
//    }
}


