/**
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package net.amoabeng.util.build;

import java.io.IOException;
import java.nio.file.Path;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static java.nio.file.Files.*;

/**
 * @author Manuel Amoabeng
 */
class CopyResourceBuilder implements ResourceBuilder {

    private final LinkBuilder linkBuilder;

    private final Map<Path, Link> cachedLinks = new HashMap<>();

    public CopyResourceBuilder(LinkBuilder linkBuilder) {
        this.linkBuilder = linkBuilder;
    }

    @Override
    public List<Link> build(FileSource fileSource) throws IOException {
        List<Link> links = new ArrayList<>();
        Path sourceRoot = fileSource.getSourceRoot();
        Path buildRoot = fileSource.getBuildRoot();

        for (Path path : fileSource.getPaths()) {

            Path buildPath = buildRoot.resolve(path);
            Path rootPath = sourceRoot.resolve(path);
            Link link = cachedLinks.get(buildPath);

            if (hasChanged(buildPath, rootPath, link)) {

                byte[] data = readAllBytes(rootPath);
                createDirectories(buildPath.getParent());
                write(buildPath, data);
                link = linkBuilder.createLink(buildPath, data);
                cachedLinks.put(buildPath, link);
            }
            links.add(link);
        }
        return links;
    }

    private boolean hasChanged(Path buildPath, Path rootPath, Link link) throws IOException {
        return
                link == null ||
                !exists(buildPath) ||
                getLastModifiedTime(buildPath).compareTo(getLastModifiedTime(rootPath)) < 0;
    }
}
