/**
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package net.amoabeng.util.build;

import java.nio.charset.Charset;
import java.nio.file.Path;
import java.nio.file.Paths;

/**
 * @author Manuel Amoabeng
 */
class CssResourceBuilderProducer implements ResourceBuilderProducer {
    
    static final String TARGET_FILE = "targetFile";
    static final String DIRECTORY_TARGET_FILE = "directoryTargetFile";


    private static final LinkBuilder CSS_LINKS = new LinkBuilder() {
        @Override
        public Link createLink(Path path, byte[] data) {
            return new Link(path, data, "<link rel=\"stylesheet\" type=\"text/css\" href=\"", "\" />", ";");
        }
    };

    private static final LinkBuilder CSS_IMPORTS = new LinkBuilder() {
        @Override
        public Link createLink(Path path, byte[] data) {
            return new Link(path, data, "@import url(\"", "\") all;", ";");
        }
    };

    @Override
    public ResourceBuilder newResourceBuilder(Settings settings) {
        Path targetFile = Paths.get(settings.get(TARGET_FILE));
        Charset charset = settings.getCharset();
        ResourceBuilder resourceBuilder;
        // TODO make sure order is equal
        if (settings.isDebug()) {
            resourceBuilder = new CopyResourceBuilder(CSS_IMPORTS);
        } else {
            Path directoryTargetFile = Paths.get(settings.get(DIRECTORY_TARGET_FILE));
            resourceBuilder = new MergeCssResourceBuilder(CSS_IMPORTS, charset, directoryTargetFile);
        }
        return new CssResourceBuilder(targetFile, charset, resourceBuilder, CSS_IMPORTS, CSS_LINKS);
    }
}
