/**
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package net.amoabeng.util.build;

import java.io.IOException;
import java.nio.file.Path;
import java.util.List;

/**
 * Represents a set of files that are part of a build.
 * @see ResourceBuilder
 * @see Link
 *
 * @author Manuel Amoabeng
 */
public interface FileSource {

    /**
     * @return The source root listed paths lie within
     */
    Path getSourceRoot();

    /**
     * @return The build root listed paths or files generated from them should be copied to
     */
    Path getBuildRoot();

    /**
     * @return A list of paths relative to the source and build root
     * @throws java.io.IOException if an error occurs resolving the paths
     */
    List<Path> getPaths() throws IOException;

}
