/**
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package net.amoabeng.util.build;

import java.nio.file.Path;
import java.nio.file.Paths;

/**
 * @author Manuel Amoabeng
 */
class JsResourceBuilderProducer implements ResourceBuilderProducer{
    
    static final String TARGET_FILE = "targetFile";

    private static final LinkBuilder JS_LINKS = new LinkBuilder() {
        @Override
        public Link createLink(Path path, byte[] data) {
            return new Link(path, data, "<script type=\"text/javascript\" src=\"", "\"></script>", ";");
        }
    };
    
    @Override
    public ResourceBuilder newResourceBuilder(Settings settings) {
        if (settings.isDebug()) {
            return new CopyResourceBuilder(JS_LINKS);
        } else {
            return new JsResourceBuilder(JS_LINKS, settings.getCharset(), Paths.get(settings.get(TARGET_FILE)));
        }
    }
}
