/**
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package net.amoabeng.util.build;

import net.amoabeng.util.io.FileUtils;

import java.io.IOException;
import java.nio.file.Path;
import java.nio.file.PathMatcher;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

/**
 * @author Manuel Amoabeng
 */
class PathMatcherFileSource implements FileSource {

    private final Path sourceRoot;
    private final Path buildRoot;
    private final PathMatcher pathMatcher;
    private final Comparator<Path> comparator;

     PathMatcherFileSource(Path sourceRoot, Path buildRoot, PathMatcher pathMatcher, Comparator<Path> comparator) {
        this.sourceRoot = sourceRoot.toAbsolutePath().normalize();
        this.buildRoot = buildRoot;
        this.pathMatcher = pathMatcher;
        this.comparator = comparator;
    }

    @Override
    public List<Path> getPaths() throws IOException {
        List<Path> paths = FileUtils.collect(sourceRoot, pathMatcher);
        paths = FileUtils.relativize(sourceRoot, paths);
        Collections.sort(paths, comparator);
        return paths;
    }

    @Override
    public Path getSourceRoot() {
        return sourceRoot;
    }

    @Override
    public Path getBuildRoot() {
        return buildRoot;
    }
}
