/**
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package net.amoabeng.util.build;

import net.amoabeng.util.io.FileUtils;

import java.nio.file.Path;
import java.nio.file.PathMatcher;
import java.util.Comparator;

/**
 * @author Manuel Amoabeng
 */
class PathMatcherFileSourceProducer implements FileSourceProducer {
    
    static final String PATH_MATCHER = "pathMatcher";

    protected static final Comparator<Path> PATH_NAME_COMPARATOR = new Comparator<Path>() {
        @Override
        public int compare(Path o1, Path o2) {
            int result;
            do {
                result = o1.getFileName().toString().compareToIgnoreCase(o2.getFileName().toString());
                o1 = o1.getParent();
                o2 = o2.getParent();
            }
            while (result == 0 && o1 != null && o2 != null);
            return result;
        }
    };

    @Override
    public FileSource newFileSource(Settings settings) {
        Path sourceRoot = settings.getSourceRoot();
        Path buildRoot = settings.getBuildRoot();
        PathMatcher pathMatcher = FileUtils.matcher(settings.get(PATH_MATCHER));
        return new PathMatcherFileSource(sourceRoot, buildRoot, pathMatcher, PATH_NAME_COMPARATOR);
    }
}
