/**
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package net.amoabeng.util.build;

import java.io.IOException;
import java.util.Map;

/**
 * Creates and configures a {@link ResourceManager}.
 * @see DefaultResourceManagerProducer
 *
 * @author Manuel Amoabeng
 */
public interface ResourceManagerProducer {

    String
            // keys for basic settings
            BASE_DIR = "baseDir",
            SOURCE_ROOT = "sourceRoot",
            BUILD_ROOT = "buildRoot",
            CHARSET = "encoding",
            MODE = "mode",
            BUILD_ON_CHANGE = "watch",

            // keys for settings by producer ([id].[key])
            TYPE = "type",
            PRODUCER_TYPE = "producerType",
            FILE_SOURCES = "fileSources",

            // known values for the property TYPE
            TEMPLATE = "template",
            BUILDER = "builder",
            FILE_SOURCE = "fileSource";

    /**
     * @param settings The settings for the manager
     * @return A configured {@link ResourceManager}
     * @throws java.io.IOException if an I/O error occurs
     */
    ResourceManager newResourceManager(Map<String, String> settings) throws IOException;
}
