/**
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package net.amoabeng.util.build;


import java.nio.charset.Charset;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Map;

import static java.util.Objects.requireNonNull;
import static net.amoabeng.util.CompareUtils.nvl;

/**
 * @author Manuel Amoabeng
 */
public final class Settings {



    static String key(String id, String key) {
        return id + "." + key;
    }

    private final String id;
    private final Map<String, String> settings;

    public Settings(String id, Map<String, String> settings) {
        this.id = id;
        this.settings = settings;
    }

    public String get(String key) {
        return nvl(settings.get(key(id, key)), settings.get(key));
    }

    boolean isDebug() {
        return "debug".equals(get("mode"));
    }

    Charset getCharset() {
        return Charset.forName(get(ResourceManagerProducer.CHARSET));
    }

    /**
     * 
     * @param key The key to get a directory for
     * @return  The directory
     */
     Path getDir(String key) {

        String baseDir = requireNonNull(settings.get(ResourceManagerProducer.BASE_DIR), "baseDir is not set");
        String baseKeyDir = nvl(settings.get(key), "");
        String keyDir = nvl(settings.get(key(id, key)), "");
        if("".equals(baseKeyDir) && "".equals(keyDir)){
            throw new IllegalArgumentException(String.format("neither %1s nor %2s set", key, key(id, key)));
        }
        return Paths.get(baseDir, baseKeyDir, keyDir);
    }
    
    public Path getSourceRoot(){
        return getDir(ResourceManagerProducer.SOURCE_ROOT);
    }
    
    public Path getBuildRoot(){
        return getDir(ResourceManagerProducer.BUILD_ROOT);
    }

    String getType() {
        return get(ResourceManagerProducer.TYPE);
    }
}
