/**
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package net.amoabeng.util.build;

import net.amoabeng.util.io.FileUtils;
import org.testng.annotations.AfterMethod;
import org.testng.annotations.BeforeMethod;

import java.io.IOException;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static org.testng.AssertJUnit.assertFalse;
import static org.testng.AssertJUnit.assertTrue;
import static org.testng.AssertJUnit.fail;

/**
 * @author Manuel Amoabeng
 */
public class DefaultResourceManagerProducerTest { // TODO fix tests

    private Path testProject;
    private ResourceManagerProducer resourceManagerProducer;
    private Map<String, String> settings;

    private List<String> jsFiles = Arrays.asList(
            "app.js",
            "app/controller/Users.js",
            "app/model/User.js",
            "app/store/Users.js",
            "app/view/Viewport.js",
            "app/view/user/List.js",
            "app/view/user/Edit.js");

    @BeforeMethod
    public void setUp() throws Exception {

        Path testProjectData = Paths.get("src", "test", "resources", "testProject");
        testProject = Paths.get("target", "testProject");

        FileUtils.delete(testProject);

        FileUtils.copy(testProjectData, testProject);
        resourceManagerProducer = new DefaultResourceManagerProducer();
        settings = new HashMap<>();
        settings.put("baseDir", testProject.toString());
        settings.put("buildRoot", "target/testProject");
    }

    @AfterMethod
    public void tearDown() throws Exception {
        FileUtils.delete(testProject);
    }


//    @Test
    public void testBuildDebug() throws IOException {
        settings.put("mode", "debug");
        resourceManagerProducer.newResourceManager(settings).build();


        Path template = testProject.resolve("target/testProject/index.html");
        assertTrue(Files.exists(template));
        List<String> templateContent = Files.readAllLines(template, Charset.defaultCharset());

        Path js = testProject.resolve("target/testProject/js");
        assertTrue(Files.exists(js));


        for (String jsFile : jsFiles) {
            assertTrue(Files.exists(js.resolve(jsFile)));
            assertContainsString("js/" + jsFile, templateContent);
        }
    }

//    @Test
    public void testBuildProduction() throws IOException {
        resourceManagerProducer.newResourceManager(settings).build();


        Path template = testProject.resolve("target/testProject/index.html");
        assertTrue(Files.exists(template));
        List<String> templateContent = Files.readAllLines(template, Charset.defaultCharset());

        Path js = testProject.resolve("target/testProject/js");
        assertTrue(Files.exists(js));

        for (String jsFile : jsFiles) {
            assertFalse(Files.exists(js.resolve(jsFile)));
        }

        assertTrue(Files.exists(js.resolve("all.js")));
        assertContainsString("js/all.js", templateContent);
    }

    private void assertContainsString(String pattern, List<String> strings) {
        for (String string : strings) {
            if (string.contains(pattern)) {
                return;
            }
        }
        fail("String " + pattern + "not found");
    }
}
