/**
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package net.amoabeng.util.build;

import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.HashMap;
import java.util.Map;

import static org.testng.AssertJUnit.assertEquals;
import static org.testng.AssertJUnit.assertNull;

/**
 * @author Manuel Amoabeng
 */
public class SettingsTest {

    Settings settings;

    @BeforeMethod
    public void beforeMethod() {
        Map<String, String> settingsMap = new HashMap<>();
        settingsMap.put(ResourceManagerProducer.BASE_DIR, "someDir");
        settingsMap.put("test.foo", "FILE.test.foo");
        settingsMap.put("foo", "FILE.foo");
        settingsMap.put("test.bar", "FILE.test.bar");
        settingsMap.put("baz", "FILE.baz");

        settings = new Settings("test", settingsMap);
    }


    @Test
    public void testGetPath1() throws Exception {
        Path fooFile = settings.getDir("foo");
        assertEquals(Paths.get("someDir", "FILE.foo", "FILE.test.foo"), fooFile);
    }

    @Test
    public void testGetPath2() throws Exception {
        Path barFile = settings.getDir("bar");
        assertEquals(Paths.get("someDir", "FILE.test.bar"), barFile);

    }

    @Test
    public void testGetPath3() throws Exception {
        Path bazFile = settings.getDir("baz");
        assertEquals(Paths.get("someDir", "FILE.baz"), bazFile);

    }

    @Test(expectedExceptions = IllegalArgumentException.class)
    public void testGetPath4() throws Exception {
        Path bangFile = settings.getDir("bang");
    }
}
